@@ -13,17 +13,28 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from abc import ABC
+from abc import abstractmethod
+from datetime import datetime
 import os
-import papermill
+from subprocess import CalledProcessError
+from subprocess import PIPE
+from subprocess import run
+import sys
 import time
+from typing import Dict
+from typing import List
+from typing import Optional
 
-from abc import ABC, abstractmethod
-from elyra.pipeline import PipelineProcessor, PipelineProcessorResponse, Operation
-from elyra.util.path import get_absolute_path
 from jupyter_server.gateway.managers import GatewayClient
-from subprocess import run, CalledProcessError, PIPE
+import papermill
 from traitlets import log
-from typing import Dict, List
+
+from elyra.pipeline.component_registry import ComponentRegistry
+from elyra.pipeline.pipeline import GenericOperation
+from elyra.pipeline.processor import PipelineProcessor
+from elyra.pipeline.processor import PipelineProcessorResponse
+from elyra.util.path import get_absolute_path
 
 
 class LocalPipelineProcessor(PipelineProcessor):
@@ -56,6 +67,9 @@ class LocalPipelineProcessor(PipelineProcessor):
     def type(self):
         return self._type
 
+    def get_components(self):
+        return ComponentRegistry.get_generic_components()
+
     def process(self, pipeline):
         """
         Process a pipeline locally.
@@ -67,13 +81,24 @@ class LocalPipelineProcessor(PipelineProcessor):
         self.log_pipeline_info(pipeline.name, "processing pipeline")
         t0_all = time.time()
 
+        # This unique run identifier is made available to all
+        # notebooks | scripts in environment variable ELYRA_RUN_NAME
+        # during pipeline execution. The id itself is not persisted
+        # after the run completes.
+        # The motivation is that notebooks | scripts might want to generate
+        # artifact names that are unique for each run to avoid overwriting.
+        # For example, a saved model file might be named
+        # `my-trained-model-{ELYRA_RUN_NAME}.ext`.
+        elyra_run_name = f'{pipeline.name}-{datetime.now().strftime("%m%d%H%M%S")}'
+
         # Sort operations based on dependency graph (topological order)
         operations = PipelineProcessor._sort_operations(pipeline.operations)
         for operation in operations:
+            assert isinstance(operation, GenericOperation)
             try:
                 t0 = time.time()
                 operation_processor = self._operation_processor_registry[operation.classifier]
-                operation_processor.process(operation)
+                operation_processor.process(operation, elyra_run_name)
                 self.log_pipeline_info(pipeline.name, f"completed {operation.filename}",
                                        operation_name=operation.name,
                                        duration=(time.time() - t0))
@@ -112,9 +137,17 @@ class OperationProcessor(ABC):
         return self._operation_name
 
     @abstractmethod
-    def process(self, operation: Operation):
+    def process(self, operation: GenericOperation, elyra_run_name: str):
         raise NotImplementedError
 
+    @staticmethod
+    def _collect_envs(operation: GenericOperation, elyra_run_name: str) -> Dict:
+        envs = os.environ.copy()  # Make sure this process's env is "available" in the kernel subprocess
+        envs.update(operation.env_vars_as_dict())
+        envs['ELYRA_RUNTIME_ENV'] = "local"  # Special case
+        envs['ELYRA_RUN_NAME'] = elyra_run_name
+        return envs
+
 
 class FileOperationProcessor(OperationProcessor):
 
@@ -129,7 +162,7 @@ class FileOperationProcessor(OperationProcessor):
         return self._operation_name
 
     @abstractmethod
-    def process(self, operation: Operation):
+    def process(self, operation: GenericOperation, elyra_run_name: str):
         raise NotImplementedError
 
     def get_valid_filepath(self, op_filename: str) -> str:
@@ -140,7 +173,10 @@ class FileOperationProcessor(OperationProcessor):
             raise ValueError(f'Not a file: {filepath}')
         return filepath
 
-    def log_and_raise(self, file_name: str, ex: Exception) -> None:
+    def log_and_raise(self,
+                      file_name: str,
+                      ex: Exception,
+                      data_capture_msg: Optional[str] = None) -> None:
         """Log and raise the exception that occurs when processing file_name.
 
         If the exception's message is longer than MAX_ERROR_LEN, it will be
@@ -148,6 +184,8 @@ class FileOperationProcessor(OperationProcessor):
         will be logged.
         """
         self.log.error(f'Error executing {file_name}: {str(ex)}')
+        if data_capture_msg:
+            self.log.info(data_capture_msg)
         truncated_msg = FileOperationProcessor._truncate_msg(str(ex))
         raise RuntimeError(f'({file_name}): {truncated_msg}') from ex
 
@@ -172,7 +210,7 @@ class FileOperationProcessor(OperationProcessor):
 class NotebookOperationProcessor(FileOperationProcessor):
     _operation_name = 'execute-notebook-node'
 
-    def process(self, operation: Operation):
+    def process(self, operation: GenericOperation, elyra_run_name: str):
         filepath = self.get_valid_filepath(operation.filename)
 
         file_dir = os.path.dirname(filepath)
@@ -183,7 +221,7 @@ class NotebookOperationProcessor(FileOperationProcessor):
         # We'll always use the ElyraEngine.  This engine is essentially the default Papermill engine
         # but allows for environment variables to be passed to the kernel process (via 'kernel_env').
         # If the current notebook server is running with Enterprise Gateway configured, we will also
-        # point the 'kernel_manager_class' to our HTTPKernelManager so that notebooks run as they
+        # point the 'kernel_manager_class' to GatewayKernelManager so that notebooks run as they
         # would outside of Elyra.  Current working directory (cwd) is specified both for where papermill
         # runs the notebook (cwd) and where the directory of the kernel process (kernel_cwd).  The latter
         # of which is important when EG is configured.
@@ -191,11 +229,9 @@ class NotebookOperationProcessor(FileOperationProcessor):
         additional_kwargs['engine_name'] = "ElyraEngine"
         additional_kwargs['cwd'] = file_dir  # For local operations, papermill runs from this dir
         additional_kwargs['kernel_cwd'] = file_dir
-        envs = os.environ.copy()  # Make sure this process's env is "available" in the kernel subprocess
-        envs.update(operation.env_vars_as_dict())
-        additional_kwargs['kernel_env'] = envs
+        additional_kwargs['kernel_env'] = OperationProcessor._collect_envs(operation, elyra_run_name)
         if GatewayClient.instance().gateway_enabled:
-            additional_kwargs['kernel_manager_class'] = 'elyra.pipeline.http_kernel_manager.HTTPKernelManager'
+            additional_kwargs['kernel_manager_class'] = 'jupyter_server.gateway.managers.GatewayKernelManager'
 
         t0 = time.time()
         try:
@@ -224,7 +260,7 @@ class ScriptOperationProcessor(FileOperationProcessor):
     def get_argv(self, filepath) -> List[str]:
         raise NotImplementedError
 
-    def process(self, operation: Operation):
+    def process(self, operation: GenericOperation, elyra_run_name: str):
         filepath = self.get_valid_filepath(operation.filename)
 
         file_dir = os.path.dirname(filepath)
@@ -233,15 +269,19 @@ class ScriptOperationProcessor(FileOperationProcessor):
         self.log.debug(f'Processing {self._script_type} script: {filepath}')
 
         argv = self.get_argv(filepath)
-
-        envs = os.environ.copy()  # Make sure this process's env is "available" in subprocess
-        envs.update(operation.env_vars_as_dict())
+        envs = OperationProcessor._collect_envs(operation, elyra_run_name)
+        data_capture_msg = f"Data capture for previous error:\n"\
+                           f" command: {' '.join(argv)}\n"\
+                           f" working directory: {file_dir}\n"\
+                           f" environment variables: {envs}"
         t0 = time.time()
         try:
             run(argv, cwd=file_dir, env=envs, check=True, stderr=PIPE)
         except CalledProcessError as cpe:
             error_msg = str(cpe.stderr.decode())
             self.log.error(f'Error executing {file_name}: {error_msg}')
+            # Log process information to aid with troubleshooting
+            self.log.info(data_capture_msg)
 
             error_trim_index = error_msg.rfind('\n', 0, error_msg.rfind('Error'))
             if error_trim_index != -1:
@@ -249,7 +289,7 @@ class ScriptOperationProcessor(FileOperationProcessor):
             else:
                 raise RuntimeError(f'({file_name})') from cpe
         except Exception as ex:
-            self.log_and_raise(file_name, ex)
+            self.log_and_raise(file_name, ex, data_capture_msg)
 
         t1 = time.time()
         duration = (t1 - t0)
@@ -261,7 +301,7 @@ class PythonScriptOperationProcessor(ScriptOperationProcessor):
     _script_type = 'Python'
 
     def get_argv(self, file_path) -> List[str]:
-        return ['python3', file_path, '--PYTHONHOME', os.path.dirname(file_path)]
+        return [f"{sys.executable}", file_path]
 
 
 class RScriptOperationProcessor(ScriptOperationProcessor):
