@@ -32,7 +32,7 @@ PIPELINE_FILE = 'resources/sample_pipelines/pipeline_dependency_complex.json'
 
 
 @pytest.fixture
-def processor():
+def processor(setup_factory_data):
     processor = AirflowPipelineProcessor(os.getcwd())
     return processor
 
@@ -377,7 +377,10 @@ def test_unique_operation_name_non_existent(processor):
 
 def test_process_list_value_function(processor):
     # Test values that will be successfully converted to list
+    assert processor._process_list_value("") == []
+    assert processor._process_list_value(None) == []
     assert processor._process_list_value("[]") == []
+    assert processor._process_list_value("None") == []
     assert processor._process_list_value("['elem1']") == ["elem1"]
     assert processor._process_list_value("['elem1', 'elem2', 'elem3']") == ["elem1", "elem2", "elem3"]
     assert processor._process_list_value("  ['elem1',   'elem2' , 'elem3']  ") == ["elem1", "elem2", "elem3"]
@@ -387,7 +390,6 @@ def test_process_list_value_function(processor):
 
     # Test values that will not be successfully converted to list
     # Surrounding quotes are added to string values for correct DAG render
-    assert processor._process_list_value("") == "\"\""
     assert processor._process_list_value("[[]") == "\"[[]\""
     assert processor._process_list_value("[elem1, elem2]") == "\"[elem1, elem2]\""
     assert processor._process_list_value("elem1, elem2") == "\"elem1, elem2\""
@@ -397,7 +399,10 @@ def test_process_list_value_function(processor):
 
 def test_process_dictionary_value_function(processor):
     # Test values that will be successfully converted to dictionary
+    assert processor._process_dictionary_value("") == {}
+    assert processor._process_dictionary_value(None) == {}
     assert processor._process_dictionary_value("{}") == {}
+    assert processor._process_dictionary_value("None") == {}
     assert processor._process_dictionary_value("{'key': 'value'}") == {"key": "value"}
 
     dict_as_str = "{'key1': 'value', 'key2': 'value'}"
@@ -432,7 +437,6 @@ def test_process_dictionary_value_function(processor):
 
     # Test values that will not be successfully converted to dictionary
     # Surrounding quotes are added to string values for correct DAG render
-    assert processor._process_dictionary_value("") == "\"\""
     assert processor._process_dictionary_value("{{}") == "\"{{}\""
     assert processor._process_dictionary_value("{key1: value, key2: value}") == "\"{key1: value, key2: value}\""
     assert processor._process_dictionary_value("  { key1: value, key2: value }  ") == "\"{ key1: value, key2: value }\""
